// GSpaceShip.cpp: implementation of the GSpaceShip class.
//
//////////////////////////////////////////////////////////////////////

#include "ph.h"
#include "GSpaceShip.h"
#include "GShoot.h"
#include "GEngine.h"
#include "H3DModel.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

// BERNY: stejny pripad, jako GShoot
GSpaceShip::GSpaceShip(GEngine *engine, H3DModel *model3D, H3DModel *projectil3D)
 : GActiveObject(engine, model3D)
{
	m_projectil3D = projectil3D;
   // typ objektu
	m_type = GOBJ_SHIP;
	
	// nastaveni casovace
   m_start_time = 25;
   m_bAsync     = FALSE;
   SetPeriod(25, 0, FALSE);

	// nastaveni lode
	m_acceleration = 0.1f;
	m_speed = 1.0f;
	m_weapon_heated = 0;
	m_lives = 100;

	// nastaveni velikosti lode
	m_size.x = 2.8;
	m_size.y = 0.9;
	m_size.z = 10;
	
	m_rotation.x = 0;
	m_rotation.y = 0;
	m_rotation.z = 0;

	m_rot_y = 0;
	
	m_rot_dx = 1;

	m_rotation.x = (rand()%60) - 30;
}

GSpaceShip::~GSpaceShip()
{

}

void GSpaceShip::DoEvent()
{
	GActiveObject::DoEvent();

	// rotovani
	if (m_rot_y < m_rotation.y) m_rot_y += 10;
	if (m_rot_y > m_rotation.y) m_rot_y -= 10;
	if (m_rotation.x >  30) m_rot_dx = -1;
	if (m_rotation.x < -30) m_rot_dx =  1;
	m_rotation.x += m_rot_dx;

	// Omezeni pohybu
	if (m_position.x >  LIMIT_X) m_position.x =  LIMIT_X;
	if (m_position.x < -LIMIT_X) m_position.x = -LIMIT_X;
	if (m_position.y >  LIMIT_Y) m_position.y =  LIMIT_Y;
	if (m_position.y < -LIMIT_Y) m_position.y = -LIMIT_Y;

	// strelba
	if (m_action && m_weapon_heated == 0 && m_lives > 0) {

		GShoot *shoot = new GShoot(m_engine, m_projectil3D, this);

		// zjistime natoceni raketky
		if (m_rotation.y == 0) shoot->m_left = true;
		else shoot->m_right = true;

		// kopie pozice i pohybu
		shoot->m_position = m_position;
		shoot->m_moveing  = m_moveing;
		shoot->m_rotation = m_rotation;

		// pridame strelu
		m_engine->AddObject(shoot);

		m_weapon_heated = WEAPON_HEATING_TIME;
	}

	// ochlazovani hlavne, aby slo strilet znovy
	if (m_weapon_heated) m_weapon_heated--;
}

void GSpaceShip::Render()
{
	// Zatek prostorov matice
	glPushMatrix();

	// nastavime pozici modelu

	// posunuti
	glTranslated(m_position.x, m_position.y, m_position.z); 
	
	// rotace 
	glRotated(m_rotation.x, 1.0, 0.0, 0.0); 
	glRotated(m_rot_y, 0.0, 1.0, 0.0); 
	glRotated(m_rotation.z, 0.0, 0.0, 1.0); 


	// kreslime model
	m_3Dmodel->Render();
	
	// obnoveni stare matice
	glPopMatrix();
}

/////////////////////////////////////////////////////////////////////////////////////

void GSpaceShip::LostLives(int lives)
{
	m_lives -= lives;
}

///////////////////////////////////////////////////////////////////////////////////////

bool GSpaceShip::Hitted(GActiveObject * /*object*/)
{
	return true; // jo chceme se strkat :-)
}
